@@ -15,11 +15,12 @@ use Data::Bitfield 0.04 qw( bitfield boolfield enumfield intfield signed_intfiel
 use Future::AsyncAwait;
 use Future::IO;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use constant PROTOCOL => "SPI";
 
-our %PRESET_MODES;
+my %BANDS;
+my %PRESET_MODES;
 
 my @CACHED_CONFIG = qw( APPEND_STATUS PACKET_LENGTH LENGTH_CONFIG );
 
@@ -304,6 +305,15 @@ string in the form
 
    PATABLE => "01.23.45.67.89.AB.CD.EF",
 
+The following values are also returned, derived from the actual register
+values as a convenience.
+
+   carrier_frequency => "800.000MHz",
+   channel_spacing   => "191.951.kHz",
+   deviation         => "47.607kHz",
+
+   data_rate         => "115.1kbps",
+
 =cut
 
 sub _tohex   { return sprintf "%v02X", $_[0] }
@@ -324,6 +334,25 @@ async sub read_config
       ),
    );
 
+   # Post-convert some derived fields just for user convenience
+   my $fosc = $self->{fosc};
+
+   my $channel_spacing = $fosc * ( 256 + $config{CHANSPC_M} ) * 2 ** $config{CHANSPC_E} / 2**18;
+
+   $config{channel_spacing} = sprintf "%.3fkHz", $channel_spacing / 1E3;
+
+   $config{carrier_frequency} = sprintf "%.3fMHz",
+      ( $fosc * $config{FREQ} / 2**16 + $config{CHAN} * $channel_spacing ) / 1E6;
+
+   my $mod_format = $config{MOD_FORMAT};
+   if( $mod_format =~ m/-FSK$|^GFSK$/ ) {
+      $config{deviation} = sprintf "%.3fkHz",
+         $fosc * ( 8 + $config{DEVIATION_M} ) * 2 ** $config{DEVIATION_E} / 2**17 / 1E3;
+   }
+
+   $config{data_rate} = sprintf "%.1fkbps",
+      $fosc * ( 256 + $config{DRATE_M} ) * 2 ** $config{DRATE_E} / 2**28 / 1E3;
+
    $self->{"CONFIG_$_"} = $config{$_} for @CACHED_CONFIG;
    return %config;
 }
@@ -341,6 +370,14 @@ The following additional lowercase-named keys are also provided as shortcuts.
 
 =over 4
 
+=item * band => STRING
+
+A convenient shortcut to setting the C<FREQ> and C<PATABLE> configuration to
+one of the standard ISM bands. The names of these bands are
+
+   433MHz
+   868MHz
+
 =item * mode => STRING
 
 A convenient shortcut to setting the configuration state to one of the presets
@@ -361,9 +398,9 @@ async sub change_config
    my $self = shift;
    my %changes = @_;
 
-   my %config = defined $self->{CONFIG}
-      ? unpack_CONFIG( $self->{CONFIG} )
-      : await $self->read_config;
+   defined $self->{CONFIG} or await $self->read_config;
+   # Use unpack_CONFIG() directly to avoid the derived keys
+   my %config = unpack_CONFIG( $self->{CONFIG} );
 
    if( defined( my $mode = delete $changes{mode} ) ) {
       $PRESET_MODES{$mode} or
@@ -372,6 +409,13 @@ async sub change_config
       %config = ( %config, $PRESET_MODES{common}->%*, $PRESET_MODES{$mode}->%* );
    }
 
+   if( defined( my $band = delete $changes{band} ) ) {
+      $BANDS{$band} or
+         croak "Unrecognised band name '$band'";
+
+      %config = ( %config, $BANDS{$band}->%* );
+   }
+
    %config = ( %config, %changes );
    my $newpatable = delete $config{PATABLE};
    $newpatable = _fromhex $newpatable if defined $newpatable;
@@ -406,22 +450,6 @@ async sub change_config
    defined $config{$_} and $self->{"CONFIG_$_"} = $config{$_} for @CACHED_CONFIG;
 }
 
-=head2 carrier_frequency
-
-   $freq = $chip->carrier_frequency->get
-
-Returns the calculated carrier frequency in Hz, from the C<FREQ> config
-register, presuming the default main XTAL frequency of 26MHz.
-
-=cut
-
-async sub carrier_frequency
-{
-   my $self = shift;
-
-   return $self->{fosc} * { await $self->read_config }->{FREQ} / 2**16;
-}
-
 =head2 read_marcstate
 
    $state = $chip->read_marcstate->get
@@ -757,6 +785,20 @@ async sub transmit
          map { m/(.*?)=(.*)/ } split m/,/, $fields
       };
    }
+
+   %BANDS = (
+      "433MHz" => {
+         FREQ    => 1091426,
+         # From the datasheet presuming 433MHz on multilayer inductors
+         PATABLE => "12.0E.1D.34.60.84.C8.C0",
+      },
+
+      "868MHz" => {
+         FREQ    => 2188650,
+         # From the datasheet presuming 868MHz on multilayer inductors
+         PATABLE => "03.0F.1E.27.50.81.CB.C2",
+      },
+   );
 }
 
 0x55AA;
@@ -783,7 +825,7 @@ Paul Evans <leonerd@leonerd.org.uk>
 
 __DATA__
 # The following data is automatically generated by update-configs.pl
-common|CCA_MODE=always,CHANSPC_E=0,FEC_EN=1,FOC_BS_CS_GATE=,FREQ=2188650,FS_AUTOCAL=on-unidle,PA_POWER=7,PO_TIMEOUT=x64,RXOFF_MODE=RX,SYNC_MODE=30/32,PATABLE=03.0F.1E.27.50.81.CB.C2
+common|CCA_MODE=always,CHANSPC_E=0,FEC_EN=1,FOC_BS_CS_GATE=,FREQ=2188650,FS_AUTOCAL=on-unidle,PA_POWER=7,PO_TIMEOUT=x64,RXOFF_MODE=RX,SYNC_MODE=30/32
 GFSK-1.2kb|CHANBW_E=3,CHANBW_M=3,DEVIATION_E=1,DEVIATION_M=5,DRATE_E=5,DRATE_M=131,FREQ_IF=8,FSCAL=2836004881,MOD_FORMAT=GFSK
 GFSK-100kb|AGC_LNA_PRIORITY=lna-first,BS_PRE_KI=KI,BS_PRE_KP=2KP,CHANBW_E=1,CHANBW_M=1,DRATE_E=11,DRATE_M=248,FILTER_LENGTH=32sa,FOC_LIMIT=BW/8,FOC_PRE_K=4K,FREQ_IF=8,FSCAL=3926523921,LNA2MIX_CURRENT=3,LNA_CURRENT=2,MAGN_TARGET=42dB,MAX_DVGA_GAIN=not-top-3,MOD_FORMAT=GFSK,WAIT_TIME=32sa
 GFSK-38.4kb|CHANBW_E=3,DEVIATION_E=3,DEVIATION_M=4,DRATE_E=10,DRATE_M=131,FREQ_IF=6,FSCAL=2836004881,MAX_DVGA_GAIN=not-top,MOD_FORMAT=GFSK
